==> hadoop-2.10.2-src.tar.gz: hadoop-2.10.2-src/hadoop-common-project/hadoop-common/src/test/java/org/apache/hadoop/fs/TestFilterFs.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.fs;

import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import java.net.URI;
import java.util.Iterator;

import junit.framework.TestCase;
import org.apache.commons.logging.Log;
import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.fs.viewfs.ConfigUtil;

public class TestFilterFs extends TestCase {

  private static final Log LOG = FileSystem.LOG;

  public static class DontCheck {
    public void checkScheme(URI uri, String supportedScheme) { }
    public Iterator<FileStatus> listStatusIterator(Path f) {
      return null;
    }
    public Iterator<LocatedFileStatus> listLocatedStatus(final Path f) {
      return null;
    }
  }
  
  public void testFilterFileSystem() throws Exception {
    for (Method m : AbstractFileSystem.class.getDeclaredMethods()) {
      if (Modifier.isStatic(m.getModifiers()))
        continue;
      if (Modifier.isPrivate(m.getModifiers()))
        continue;
      if (Modifier.isFinal(m.getModifiers()))
        continue;
      
      try {
        DontCheck.class.getMethod(m.getName(), m.getParameterTypes());
        LOG.info("Skipping " + m);
      } catch (NoSuchMethodException exc) {
        LOG.info("Testing " + m);
        try{
          FilterFs.class.getDeclaredMethod(m.getName(), m.getParameterTypes());
        }
        catch(NoSuchMethodException exc2){
          LOG.error("FilterFileSystem doesn't implement " + m);
          throw exc2;
        }
      }
    }
  }
  
  // Test that FilterFs will accept an AbstractFileSystem to be filtered which
  // has an optional authority, such as ViewFs
  public void testFilteringWithNonrequiredAuthority() throws Exception {
    Configuration conf = new Configuration();
    ConfigUtil.addLink(conf, "custom", "/mnt", URI.create("file:///"));
    FileContext fc =
        FileContext.getFileContext(URI.create("viewfs://custom/"), conf);
    new FilterFs(fc.getDefaultFileSystem()) {};
  }

}

==> hadoop-3.4.2-src.tar.gz: hadoop-3.4.2-src/hadoop-common-project/hadoop-common/src/test/java/org/apache/hadoop/fs/TestFilterFs.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.fs;

import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import java.net.URI;
import java.util.Iterator;

import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.fs.viewfs.ConfigUtil;
import org.junit.Test;
import org.slf4j.Logger;

public class TestFilterFs {

  private static final Logger LOG = FileSystem.LOG;

  public static class DontCheck {
    public void checkScheme(URI uri, String supportedScheme) { }
    public Iterator<FileStatus> listStatusIterator(Path f) {
      return null;
    }
    public Iterator<LocatedFileStatus> listLocatedStatus(final Path f) {
      return null;
    }
  }

  @Test
  public void testFilterFileSystem() throws Exception {
    for (Method m : AbstractFileSystem.class.getDeclaredMethods()) {
      if (Modifier.isStatic(m.getModifiers()))
        continue;
      if (Modifier.isPrivate(m.getModifiers()))
        continue;
      if (Modifier.isFinal(m.getModifiers()))
        continue;
      
      try {
        DontCheck.class.getMethod(m.getName(), m.getParameterTypes());
        LOG.info("Skipping " + m);
      } catch (NoSuchMethodException exc) {
        LOG.info("Testing " + m);
        try{
          FilterFs.class.getDeclaredMethod(m.getName(), m.getParameterTypes());
        }
        catch(NoSuchMethodException exc2){
          LOG.error("FilterFileSystem doesn't implement " + m);
          throw exc2;
        }
      }
    }
  }
  
  // Test that FilterFs will accept an AbstractFileSystem to be filtered which
  // has an optional authority, such as ViewFs
  @Test
  public void testFilteringWithNonrequiredAuthority() throws Exception {
    Configuration conf = new Configuration();
    ConfigUtil.addLink(conf, "custom", "/mnt", URI.create("file:///"));
    FileContext fc =
        FileContext.getFileContext(URI.create("viewfs://custom/"), conf);
    new FilterFs(fc.getDefaultFileSystem()) {};
  }

}
